# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelclass/v1/modelclass.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/modelclass/v1/modelclass.proto\x12/github.com.metaprov.modelaapi.services.study.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"7\n\x14GetModelClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x7f\n\x15GetModelClassResponse\x12X\n\nmodelclass\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"\xbd\x01\n\x15ListModelClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x03 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.study.v1.ListModelClassRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x91\x01\n\x16ListModelClassResponse\x12^\n\x0cmodelclasses\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"s\n\x17\x43reateModelClassRequest\x12X\n\nmodelclass\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\"\x1a\n\x18\x43reateModelClassResponse\"\xa3\x01\n\x17UpdateModelClassRequest\x12X\n\nmodelclass\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x98\x01\n\x1e\x43reateModelClassProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12U\n\x0cmodelclasses\x18\x03 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"O\n\x1f\x43reateModelClassProfileResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"N\n\x1bGetModelClassProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06models\x18\x03 \x01(\x05\":\n\x17\x44\x65leteModelClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteModelClassResponse\"\x1a\n\x18UpdateModelClassResponse2\xbc\n\n\x11ModelClassService\x12\xc9\x01\n\x10ListModelClasses\x12\x46.github.com.metaprov.modelaapi.services.study.v1.ListModelClassRequest\x1aG.github.com.metaprov.modelaapi.services.study.v1.ListModelClassResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/modelclasses/{namespace}\x12\xc4\x01\n\x10\x43reateModelClass\x12H.github.com.metaprov.modelaapi.services.study.v1.CreateModelClassRequest\x1aI.github.com.metaprov.modelaapi.services.study.v1.CreateModelClassResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/modelclasses:\x01*\x12\xcb\x01\n\rGetModelClass\x12\x45.github.com.metaprov.modelaapi.services.study.v1.GetModelClassRequest\x1a\x46.github.com.metaprov.modelaapi.services.study.v1.GetModelClassResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/modelclasses/{namespace}/{name}\x12\xfa\x01\n\x10UpdateModelClass\x12H.github.com.metaprov.modelaapi.services.study.v1.UpdateModelClassRequest\x1aI.github.com.metaprov.modelaapi.services.study.v1.UpdateModelClassResponse\"Q\x82\xd3\xe4\x93\x02K\x1a\x46/v1/studies/{modelclass.metadata.namespace}/{modelclass.metadata.name}:\x01*\x12\xd4\x01\n\x10\x44\x65leteModelClass\x12H.github.com.metaprov.modelaapi.services.study.v1.DeleteModelClassRequest\x1aI.github.com.metaprov.modelaapi.services.study.v1.DeleteModelClassResponse\"+\x82\xd3\xe4\x93\x02%*#/v1/modelclasses/{namespace}/{name}\x12\xf1\x01\n\x17\x43reateModelClassProfile\x12O.github.com.metaprov.modelaapi.services.study.v1.CreateModelClassProfileRequest\x1aP.github.com.metaprov.modelaapi.services.study.v1.CreateModelClassProfileResponse\"3\x82\xd3\xe4\x93\x02-\"+/v1/modelclasses/{namespace}/{name}/profileB1Z/github.com/metaprov/modelaapi/services/study/v1b\x06proto3')



_GETMODELCLASSREQUEST = DESCRIPTOR.message_types_by_name['GetModelClassRequest']
_GETMODELCLASSRESPONSE = DESCRIPTOR.message_types_by_name['GetModelClassResponse']
_LISTMODELCLASSREQUEST = DESCRIPTOR.message_types_by_name['ListModelClassRequest']
_LISTMODELCLASSREQUEST_LABELSENTRY = _LISTMODELCLASSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELCLASSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelClassResponse']
_CREATEMODELCLASSREQUEST = DESCRIPTOR.message_types_by_name['CreateModelClassRequest']
_CREATEMODELCLASSRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelClassResponse']
_UPDATEMODELCLASSREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelClassRequest']
_CREATEMODELCLASSPROFILEREQUEST = DESCRIPTOR.message_types_by_name['CreateModelClassProfileRequest']
_CREATEMODELCLASSPROFILERESPONSE = DESCRIPTOR.message_types_by_name['CreateModelClassProfileResponse']
_GETMODELCLASSPROFILEREQUEST = DESCRIPTOR.message_types_by_name['GetModelClassProfileRequest']
_DELETEMODELCLASSREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelClassRequest']
_DELETEMODELCLASSRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelClassResponse']
_UPDATEMODELCLASSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelClassResponse']
GetModelClassRequest = _reflection.GeneratedProtocolMessageType('GetModelClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetModelClassRequest)
  })
_sym_db.RegisterMessage(GetModelClassRequest)

GetModelClassResponse = _reflection.GeneratedProtocolMessageType('GetModelClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetModelClassResponse)
  })
_sym_db.RegisterMessage(GetModelClassResponse)

ListModelClassRequest = _reflection.GeneratedProtocolMessageType('ListModelClassRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELCLASSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ListModelClassRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ListModelClassRequest)
  })
_sym_db.RegisterMessage(ListModelClassRequest)
_sym_db.RegisterMessage(ListModelClassRequest.LabelsEntry)

ListModelClassResponse = _reflection.GeneratedProtocolMessageType('ListModelClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ListModelClassResponse)
  })
_sym_db.RegisterMessage(ListModelClassResponse)

CreateModelClassRequest = _reflection.GeneratedProtocolMessageType('CreateModelClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateModelClassRequest)
  })
_sym_db.RegisterMessage(CreateModelClassRequest)

CreateModelClassResponse = _reflection.GeneratedProtocolMessageType('CreateModelClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateModelClassResponse)
  })
_sym_db.RegisterMessage(CreateModelClassResponse)

UpdateModelClassRequest = _reflection.GeneratedProtocolMessageType('UpdateModelClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.UpdateModelClassRequest)
  })
_sym_db.RegisterMessage(UpdateModelClassRequest)

CreateModelClassProfileRequest = _reflection.GeneratedProtocolMessageType('CreateModelClassProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCLASSPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateModelClassProfileRequest)
  })
_sym_db.RegisterMessage(CreateModelClassProfileRequest)

CreateModelClassProfileResponse = _reflection.GeneratedProtocolMessageType('CreateModelClassProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCLASSPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateModelClassProfileResponse)
  })
_sym_db.RegisterMessage(CreateModelClassProfileResponse)

GetModelClassProfileRequest = _reflection.GeneratedProtocolMessageType('GetModelClassProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCLASSPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetModelClassProfileRequest)
  })
_sym_db.RegisterMessage(GetModelClassProfileRequest)

DeleteModelClassRequest = _reflection.GeneratedProtocolMessageType('DeleteModelClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.DeleteModelClassRequest)
  })
_sym_db.RegisterMessage(DeleteModelClassRequest)

DeleteModelClassResponse = _reflection.GeneratedProtocolMessageType('DeleteModelClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.DeleteModelClassResponse)
  })
_sym_db.RegisterMessage(DeleteModelClassResponse)

UpdateModelClassResponse = _reflection.GeneratedProtocolMessageType('UpdateModelClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclass.v1.modelclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.UpdateModelClassResponse)
  })
_sym_db.RegisterMessage(UpdateModelClassResponse)

_MODELCLASSSERVICE = DESCRIPTOR.services_by_name['ModelClassService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/metaprov/modelaapi/services/study/v1'
  _LISTMODELCLASSREQUEST_LABELSENTRY._options = None
  _LISTMODELCLASSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELCLASSSERVICE.methods_by_name['ListModelClasses']._options = None
  _MODELCLASSSERVICE.methods_by_name['ListModelClasses']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/modelclasses/{namespace}'
  _MODELCLASSSERVICE.methods_by_name['CreateModelClass']._options = None
  _MODELCLASSSERVICE.methods_by_name['CreateModelClass']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/modelclasses:\001*'
  _MODELCLASSSERVICE.methods_by_name['GetModelClass']._options = None
  _MODELCLASSSERVICE.methods_by_name['GetModelClass']._serialized_options = b'\202\323\344\223\002%\022#/v1/modelclasses/{namespace}/{name}'
  _MODELCLASSSERVICE.methods_by_name['UpdateModelClass']._options = None
  _MODELCLASSSERVICE.methods_by_name['UpdateModelClass']._serialized_options = b'\202\323\344\223\002K\032F/v1/studies/{modelclass.metadata.namespace}/{modelclass.metadata.name}:\001*'
  _MODELCLASSSERVICE.methods_by_name['DeleteModelClass']._options = None
  _MODELCLASSSERVICE.methods_by_name['DeleteModelClass']._serialized_options = b'\202\323\344\223\002%*#/v1/modelclasses/{namespace}/{name}'
  _MODELCLASSSERVICE.methods_by_name['CreateModelClassProfile']._options = None
  _MODELCLASSSERVICE.methods_by_name['CreateModelClassProfile']._serialized_options = b'\202\323\344\223\002-\"+/v1/modelclasses/{namespace}/{name}/profile'
  _GETMODELCLASSREQUEST._serialized_start=323
  _GETMODELCLASSREQUEST._serialized_end=378
  _GETMODELCLASSRESPONSE._serialized_start=380
  _GETMODELCLASSRESPONSE._serialized_end=507
  _LISTMODELCLASSREQUEST._serialized_start=510
  _LISTMODELCLASSREQUEST._serialized_end=699
  _LISTMODELCLASSREQUEST_LABELSENTRY._serialized_start=654
  _LISTMODELCLASSREQUEST_LABELSENTRY._serialized_end=699
  _LISTMODELCLASSRESPONSE._serialized_start=702
  _LISTMODELCLASSRESPONSE._serialized_end=847
  _CREATEMODELCLASSREQUEST._serialized_start=849
  _CREATEMODELCLASSREQUEST._serialized_end=964
  _CREATEMODELCLASSRESPONSE._serialized_start=966
  _CREATEMODELCLASSRESPONSE._serialized_end=992
  _UPDATEMODELCLASSREQUEST._serialized_start=995
  _UPDATEMODELCLASSREQUEST._serialized_end=1158
  _CREATEMODELCLASSPROFILEREQUEST._serialized_start=1161
  _CREATEMODELCLASSPROFILEREQUEST._serialized_end=1313
  _CREATEMODELCLASSPROFILERESPONSE._serialized_start=1315
  _CREATEMODELCLASSPROFILERESPONSE._serialized_end=1394
  _GETMODELCLASSPROFILEREQUEST._serialized_start=1396
  _GETMODELCLASSPROFILEREQUEST._serialized_end=1474
  _DELETEMODELCLASSREQUEST._serialized_start=1476
  _DELETEMODELCLASSREQUEST._serialized_end=1534
  _DELETEMODELCLASSRESPONSE._serialized_start=1536
  _DELETEMODELCLASSRESPONSE._serialized_end=1562
  _UPDATEMODELCLASSRESPONSE._serialized_start=1564
  _UPDATEMODELCLASSRESPONSE._serialized_end=1590
  _MODELCLASSSERVICE._serialized_start=1593
  _MODELCLASSSERVICE._serialized_end=2933
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/offlinefeaturestored/v1/offlinefeaturestored.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYgithub.com/metaprov/modelaapi/services/offlinefeaturestored/v1/offlinefeaturestored.proto\x12>github.com.metaprov.modelaapi.services.offlinefeaturestored.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"u\n\x1eGenerateTrainingDatasetRequest\x12S\n\x05model\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\"/\n\x1fGenerateTrainingDatasetResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\"\r\n\x0bSyncRequest\"\x0e\n\x0cSyncResponse2\xa1\x03\n\x1aOfflineFeatureStoreService\x12\xa3\x01\n\x04Sync\x12K.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.SyncRequest\x1aL.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.SyncResponse\"\x00\x12\xdc\x01\n\x17GenerateTrainingDataset\x12^.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GenerateTrainingDatasetRequest\x1a_.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GenerateTrainingDatasetResponse\"\x00\x42@Z>github.com/metaprov/modelaapi/services/offlinefeaturestored/v1b\x06proto3')



_GENERATETRAININGDATASETREQUEST = DESCRIPTOR.message_types_by_name['GenerateTrainingDatasetRequest']
_GENERATETRAININGDATASETRESPONSE = DESCRIPTOR.message_types_by_name['GenerateTrainingDatasetResponse']
_SYNCREQUEST = DESCRIPTOR.message_types_by_name['SyncRequest']
_SYNCRESPONSE = DESCRIPTOR.message_types_by_name['SyncResponse']
GenerateTrainingDatasetRequest = _reflection.GeneratedProtocolMessageType('GenerateTrainingDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETRAININGDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GenerateTrainingDatasetRequest)
  })
_sym_db.RegisterMessage(GenerateTrainingDatasetRequest)

GenerateTrainingDatasetResponse = _reflection.GeneratedProtocolMessageType('GenerateTrainingDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETRAININGDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GenerateTrainingDatasetResponse)
  })
_sym_db.RegisterMessage(GenerateTrainingDatasetResponse)

SyncRequest = _reflection.GeneratedProtocolMessageType('SyncRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNCREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.SyncRequest)
  })
_sym_db.RegisterMessage(SyncRequest)

SyncResponse = _reflection.GeneratedProtocolMessageType('SyncResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYNCRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.SyncResponse)
  })
_sym_db.RegisterMessage(SyncResponse)

_OFFLINEFEATURESTORESERVICE = DESCRIPTOR.services_by_name['OfflineFeatureStoreService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z>github.com/metaprov/modelaapi/services/offlinefeaturestored/v1'
  _GENERATETRAININGDATASETREQUEST._serialized_start=372
  _GENERATETRAININGDATASETREQUEST._serialized_end=489
  _GENERATETRAININGDATASETRESPONSE._serialized_start=491
  _GENERATETRAININGDATASETRESPONSE._serialized_end=538
  _SYNCREQUEST._serialized_start=540
  _SYNCREQUEST._serialized_end=553
  _SYNCRESPONSE._serialized_start=555
  _SYNCRESPONSE._serialized_end=569
  _OFFLINEFEATURESTORESERVICE._serialized_start=572
  _OFFLINEFEATURESTORESERVICE._serialized_end=989
# @@protoc_insertion_point(module_scope)
